#  Copyright (C) 2024
#  ABM, Moscow
#
#  UNPUBLISHED PROPRIETARY MATERIAL.
#  ALL RIGHTS RESERVED.
#
#  Authors: Mike Orlov <m.orlov@abm-jsc.ru>
def repr_exception(exception: Exception) -> str:
    result = type(exception).__name__
    if str(exception):
        result += f": {exception}"
    return result
